@@ -9,7 +9,7 @@ function(x, squash=FALSE)
   ## squash: remove spaces from labels (default: TRUE)
   ## NB: NO ERROR CHECKING SO BE CAREFUL
 
-  require("gdata")
+  ## require("gdata")  # obsolete in current R as in Depends/Imports
   
   ## set NA's to "" otherwise a problem
   if (is.factor(x))
@@ -17,9 +17,9 @@ function(x, squash=FALSE)
   x[is.na(x)] <- ""
   ## and of course - what about leading/trailing spaces or just spaces...
   if (is.factor(x)) {
-    levels(x) <- trim(levels(x))
+    levels(x) <- gdata::trim(levels(x))
     } else {
-      x <- trim(x)
+      x <- gdata::trim(x)
     }
   
   if (x[1] == "") cat("Warning: first value of vector is blank!\n")
